[Libreoffice-commits] core.git: framework/inc framework/source include/unotools odk/examples unotools/source

Tor Lillqvist tml at collabora.com
Sun Apr 6 10:28:59 PDT 2014


 framework/inc/dispatch/dispatchprovider.hxx                                   |    2 -
 framework/inc/dispatch/interceptionhelper.hxx                                 |    2 -
 framework/inc/dispatch/menudispatcher.hxx                                     |    2 -
 framework/inc/dispatch/popupmenudispatcher.hxx                                |    2 -
 framework/inc/helper/dockingareadefaultacceptor.hxx                           |    2 -
 framework/inc/helper/ocomponentaccess.hxx                                     |    8 ++--
 framework/inc/helper/ocomponentenumeration.hxx                                |    2 -
 framework/inc/helper/oframes.hxx                                              |   10 ++---
 framework/inc/queries.h                                                       |    2 -
 framework/inc/services/mediatypedetectionhelper.hxx                           |    2 -
 framework/inc/targets.h                                                       |    2 -
 framework/source/fwe/classes/addonsoptions.cxx                                |   14 +++----
 framework/source/helper/oframes.cxx                                           |   10 ++---
 framework/source/services/desktop.cxx                                         |   16 ++++----
 framework/source/services/frame.cxx                                           |   18 +++++-----
 include/unotools/historyoptions.hxx                                           |    2 -
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OnewayExecutor.java |    2 -
 unotools/source/config/cmdoptions.cxx                                         |   16 ++++----
 unotools/source/config/compatibility.cxx                                      |    8 ++--
 unotools/source/config/dynamicmenuoptions.cxx                                 |   14 +++----
 unotools/source/config/extendedsecurityoptions.cxx                            |   12 +++---
 unotools/source/config/fontoptions.cxx                                        |   18 +++++-----
 unotools/source/config/historyoptions.cxx                                     |    8 ++--
 unotools/source/config/localisationoptions.cxx                                |   16 ++++----
 unotools/source/config/moduleoptions.cxx                                      |    2 -
 unotools/source/config/printwarningoptions.cxx                                |    8 ++--
 unotools/source/config/securityoptions.cxx                                    |   10 ++---
 27 files changed, 105 insertions(+), 105 deletions(-)

New commits:
commit d9701f0ebce5b06212a9361ce753f3bf17510418
Author: Tor Lillqvist <tml at collabora.com>
Date:   Sun Apr 6 20:25:20 2014 +0300

    Typo: s/ouer/our
    
    Change-Id: I0179678c6c5dd6a05b1d7d5038a901e7bf2af3de

diff --git a/framework/inc/dispatch/dispatchprovider.hxx b/framework/inc/dispatch/dispatchprovider.hxx
index 9aa7143..8f15e13 100644
--- a/framework/inc/dispatch/dispatchprovider.hxx
+++ b/framework/inc/dispatch/dispatchprovider.hxx
@@ -66,7 +66,7 @@ enum EDispatchHelper
                             - a normal frame never can create a new one by himself
 
     @attention      Use this class as member only! Never use it as baseclass.
-                    XInterface will be ambigous and we hold a weakreference to ouer OWNER - not to ouer SUPERCLASS!
+                    XInterface will be ambigous and we hold a weakreference to our OWNER - not to our SUPERCLASS!
 
     @base           OWeakObject
                         provides ref count and weak mechanism
diff --git a/framework/inc/dispatch/interceptionhelper.hxx b/framework/inc/dispatch/interceptionhelper.hxx
index 06a7c79..199c47e 100644
--- a/framework/inc/dispatch/interceptionhelper.hxx
+++ b/framework/inc/dispatch/interceptionhelper.hxx
@@ -45,7 +45,7 @@ namespace framework{
                 master/slave functionality AND using of optional features like registration of URL pattern!
 
     @attention  Don't use this class as direct member - use it dynamicly. Do not derive from this class.
-                We hold a weakreference to ouer owner not to ouer superclass.
+                We hold a weakreference to our owner not to our superclass.
  */
 class InterceptionHelper : public  ::cppu::WeakImplHelper3<
                                      css::frame::XDispatchProvider,
diff --git a/framework/inc/dispatch/menudispatcher.hxx b/framework/inc/dispatch/menudispatcher.hxx
index 7bc0671..48abdd4 100644
--- a/framework/inc/dispatch/menudispatcher.hxx
+++ b/framework/inc/dispatch/menudispatcher.hxx
@@ -58,7 +58,7 @@ typedef ::cppu::OMultiTypeInterfaceContainerHelperVar<  OUString         ,
 /*-************************************************************************************************************
     @short          helper for desktop only(!) to create new tasks on demand for dispatches
     @descr          Use this class as member only! Never use it as baseclass.
-                    XInterface will be ambigous and we hold a weakcss::uno::Reference to ouer OWNER - not to ouer SUPERCLASS!
+                    XInterface will be ambigous and we hold a weakcss::uno::Reference to our OWNER - not to our SUPERCLASS!
 
     @implements     XInterface
                     XDispatch
diff --git a/framework/inc/dispatch/popupmenudispatcher.hxx b/framework/inc/dispatch/popupmenudispatcher.hxx
index 518ed3d..82b5015 100644
--- a/framework/inc/dispatch/popupmenudispatcher.hxx
+++ b/framework/inc/dispatch/popupmenudispatcher.hxx
@@ -60,7 +60,7 @@ typedef ::cppu::OMultiTypeInterfaceContainerHelperVar<  OUString         ,
 /*-************************************************************************************************************
     @short          helper for desktop only(!) to create new tasks on demand for dispatches
     @descr          Use this class as member only! Never use it as baseclass.
-                    XInterface will be ambigous and we hold a weakcss::uno::Reference to ouer OWNER - not to our SUPERCLASS!
+                    XInterface will be ambigous and we hold a weakcss::uno::Reference to our OWNER - not to our SUPERCLASS!
 
     @implements     XInterface
                     XDispatch
diff --git a/framework/inc/helper/dockingareadefaultacceptor.hxx b/framework/inc/helper/dockingareadefaultacceptor.hxx
index 1920a7b7..eed6faf 100644
--- a/framework/inc/helper/dockingareadefaultacceptor.hxx
+++ b/framework/inc/helper/dockingareadefaultacceptor.hxx
@@ -47,7 +47,7 @@ class DockingAreaDefaultAcceptor    :   public ::cppu::WeakImplHelper1< ::com::s
             @seealso    class Desktop
             @seealso    class OTasksEnumeration
 
-            @param      "xOwner" is a reference to ouer owner and must be the desktop!
+            @param      "xOwner" is a reference to our owner and must be the desktop!
             @param      "pTasks" is a pointer to the taskcontainer of the desktop. We need it to create a new enumeration.
             @onerror    Do nothing and reset this object to default with an empty list.
         *//*-*****************************************************************************************************/
diff --git a/framework/inc/helper/ocomponentaccess.hxx b/framework/inc/helper/ocomponentaccess.hxx
index de46a82..82dc392 100644
--- a/framework/inc/helper/ocomponentaccess.hxx
+++ b/framework/inc/helper/ocomponentaccess.hxx
@@ -39,8 +39,8 @@ namespace framework{
 
 /*-************************************************************************************************************
     @short          implement XEnumerationAccess interface as helper to create many oneway enumeration of components
-    @descr          We share mutex and framecontainer with ouer owner and have full access to his child tasks.
-                    (Ouer owner can be the Desktop only!) We create oneway enumerations on demand. These "lists"
+    @descr          We share mutex and framecontainer with our owner and have full access to his child tasks.
+                    (Our owner can be the Desktop only!) We create oneway enumerations on demand. These "lists"
                     can be used for one time only. Step during the list from first to last element.
                     (The type of created enumerations is OComponentEnumeration.)
 
@@ -72,7 +72,7 @@ class OComponentAccess  :   public ::cppu::WeakImplHelper1< ::com::sun::star::co
             @seealso    class Desktop
             @seealso    class OComponentEnumeration
 
-            @param      "xOwner" is a reference to ouer owner and must be the desktop!
+            @param      "xOwner" is a reference to our owner and must be the desktop!
             @onerror    Do nothing and reset this object to default with an empty list.
         *//*-*****************************************************************************************************/
 
@@ -121,7 +121,7 @@ class OComponentAccess  :   public ::cppu::WeakImplHelper1< ::com::sun::star::co
             @short      standard destructor
             @descr      This method destruct an instance of this class and clear some member.
                         Don't use an instance of this class as normal member. Use it dynamicly with a pointer.
-                        We hold a weakreference to ouer owner and not to ouer superclass!
+                        We hold a weakreference to our owner and not to our superclass!
                         Thats the reason for a protected dtor.
 
             @seealso    class Desktop
diff --git a/framework/inc/helper/ocomponentenumeration.hxx b/framework/inc/helper/ocomponentenumeration.hxx
index d9a3396..d05d798 100644
--- a/framework/inc/helper/ocomponentenumeration.hxx
+++ b/framework/inc/helper/ocomponentenumeration.hxx
@@ -74,7 +74,7 @@ class OComponentEnumeration :   public ::cppu::WeakImplHelper2< ::com::sun::star
         /*-****************************************************************************************************
             @short      last chance to release all references and free memory
             @descr      This method is called, if the enumeration is used completely and has no more elements.
-                        Then we must destroy ouer list and release all references to other objects.
+                        Then we must destroy our list and release all references to other objects.
 
             @seealso    interface XEventListener
 
diff --git a/framework/inc/helper/oframes.hxx b/framework/inc/helper/oframes.hxx
index f9e52d7..010ae1b 100644
--- a/framework/inc/helper/oframes.hxx
+++ b/framework/inc/helper/oframes.hxx
@@ -37,9 +37,9 @@ namespace framework{
 
 /*-************************************************************************************************************
     @short          implement XFrames, XIndexAccess and XElementAccess interfaces as helper for services
-    @descr          Use this class as helper for these interfaces. We share mutex and framecontainer with ouer owner.
+    @descr          Use this class as helper for these interfaces. We share mutex and framecontainer with our owner.
                     The framecontainer is a member of it from type "FrameContainer". That means;
-                    we have the same information as ouer owner. In current implementation we use mutex and lock-mechanism
+                    we have the same information as our owner. In current implementation we use mutex and lock-mechanism
                     to prevent against compete access. In future we plan support of semaphore!
 
     @devstatus      deprecated
@@ -50,7 +50,7 @@ namespace framework{
     @base           OWeakObject
 
     @ATTENTION      Don't use this class as direct member - use it dynamicly. Do not derive from this class.
-                    We hold a weakreference to ouer owner not to ouer superclass.
+                    We hold a weakreference to our owner not to our superclass.
 
     @devstatus      deprecated
 *//*-*************************************************************************************************************/
@@ -62,7 +62,7 @@ class OFrames   :   public ::cppu::WeakImplHelper1< ::com::sun::star::frame::XFr
             @short      standard ctor
             @descr      These initialize a new instance of this class with all needed information for work.
                         We share framecontainer with owner implementation! It's a threadsafe container.
-            @param      xOwner            , reference to ouer owner. We hold a wekreference to prevent us against cross-references!
+            @param      xOwner            , reference to our owner. We hold a wekreference to prevent us against cross-references!
             @param      pFrameContainer   , pointer to shared framecontainer of owner. It's valid only, if weakreference is valid!
         *//*-*****************************************************************************************************/
          OFrames(   const   css::uno::Reference< css::frame::XFrame >&              xOwner          ,
@@ -72,7 +72,7 @@ class OFrames   :   public ::cppu::WeakImplHelper1< ::com::sun::star::frame::XFr
 
         /*-****************************************************************************************************
             @short      append frame to container
-            @descr      We share the container with ouer owner. We can do this only, if no lock is set on container.
+            @descr      We share the container with our owner. We can do this only, if no lock is set on container.
                         Valid references are accepted only!
 
             @seealso    class FrameContainer
diff --git a/framework/inc/queries.h b/framework/inc/queries.h
index 968d083..4ba853c 100644
--- a/framework/inc/queries.h
+++ b/framework/inc/queries.h
@@ -30,7 +30,7 @@ namespace framework{
 
 /*-************************************************************************************************************
     @short          These values describe our supported queries for type, filter ... properties.
-                    They are used by our FilterFactory or ouer TypeDetection to return
+                    They are used by our FilterFactory or our TypeDetection to return
                     subsets of our cached configuration.
 *//*-*************************************************************************************************************/
 #define BASE_QUERY_ALL                                  DECLARE_ASCII("_query_all"     )
diff --git a/framework/inc/services/mediatypedetectionhelper.hxx b/framework/inc/services/mediatypedetectionhelper.hxx
index a6690bc..3c0ca99 100644
--- a/framework/inc/services/mediatypedetectionhelper.hxx
+++ b/framework/inc/services/mediatypedetectionhelper.hxx
@@ -56,7 +56,7 @@ class MediaTypeDetectionHelper  :   public ::cppu::WeakImplHelper2< ::com::sun::
         /*-****************************************************************************************************
             @short      standard ctor
             @descr      These initialize a new instance of this class with all needed information for work.
-            @param      "xFactory", reference to factory which has created ouer owner(!). We can use these to create new uno-services.
+            @param      "xFactory", reference to factory which has created our owner(!). We can use these to create new uno-services.
         *//*-*****************************************************************************************************/
 
          MediaTypeDetectionHelper( const css::uno::Reference< css::lang::XMultiServiceFactory >& xFactory );
diff --git a/framework/inc/targets.h b/framework/inc/targets.h
index d574e90..a266bc5 100644
--- a/framework/inc/targets.h
+++ b/framework/inc/targets.h
@@ -28,7 +28,7 @@ namespace framework{
 
 #define SPECIALTARGET_ASCII_SELF            "_self"                             // The frame himself is searched.
 #define SPECIALTARGET_ASCII_PARENT          "_parent"                           // The direct parent frame is searched.
-#define SPECIALTARGET_ASCII_TOP             "_top"                              // Search at ouer parents for the first task (if any exist) or a frame without a parent.
+#define SPECIALTARGET_ASCII_TOP             "_top"                              // Search at our parents for the first task (if any exist) or a frame without a parent.
 #define SPECIALTARGET_ASCII_BLANK           "_blank"                            // Create a new task.
 #define SPECIALTARGET_ASCII_DEFAULT         "_default"                          // Create a new task or recycle an existing one
 #define SPECIALTARGET_ASCII_BEAMER          "_beamer"                           // special frame in hierarchy
diff --git a/framework/source/fwe/classes/addonsoptions.cxx b/framework/source/fwe/classes/addonsoptions.cxx
index 3b5bb96..2c7c99c 100644
--- a/framework/source/fwe/classes/addonsoptions.cxx
+++ b/framework/source/fwe/classes/addonsoptions.cxx
@@ -426,8 +426,8 @@ AddonsOptions_Impl::AddonsOptions_Impl()
 
     ReadConfigurationData();
 
-    // Enable notification mechanism of ouer baseclass.
-    // We need it to get information about changes outside these class on ouer used configuration keys!
+    // Enable notification mechanism of our baseclass.
+    // We need it to get information about changes outside these class on our used configuration keys!
     Sequence< OUString > aNotifySeq( 1 );
     aNotifySeq[0] = "AddonUI";
     EnableNotification( aNotifySeq );
@@ -1658,9 +1658,9 @@ AddonsOptions::AddonsOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new AddonsOptions_Impl;
@@ -1673,10 +1673,10 @@ AddonsOptions::~AddonsOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
@@ -1792,7 +1792,7 @@ Mutex& AddonsOptions::GetOwnStaticMutex()
         // ... we must create a new one. Protect follow code with the global mutex -
         // It must be - we create a static variable!
         MutexGuard aGuard( Mutex::getGlobalMutex() );
-        // We must check our pointer again - because it can be that another instance of ouer class will be fastr then these!
+        // We must check our pointer again - because it can be that another instance of our class will be fastr then these!
         if( pMutex == NULL )
         {
             // Create the new mutex and set it for return on static variable.
diff --git a/framework/source/helper/oframes.cxx b/framework/source/helper/oframes.cxx
index 8234a5a..9c41a19 100644
--- a/framework/source/helper/oframes.cxx
+++ b/framework/source/helper/oframes.cxx
@@ -74,7 +74,7 @@ void SAL_CALL OFrames::append( const css::uno::Reference< XFrame >& xFrame ) thr
         // Set owner of this instance as parent of the new frame in container!
         xFrame->setCreator( xOwner );
     }
-    // Else; Do nothing! Ouer owner is dead.
+    // Else; Do nothing! Our owner is dead.
     SAL_WARN_IF( !xOwner.is(), "fwk", "OFrames::append():Our owner is dead - you can't append any frames ...!" );
 }
 
@@ -98,7 +98,7 @@ void SAL_CALL OFrames::remove( const css::uno::Reference< XFrame >& xFrame ) thr
         // This must do the caller of this method himself.
         // See documentation of interface XFrames for further information.
     }
-    // Else; Do nothing! Ouer owner is dead.
+    // Else; Do nothing! Our owner is dead.
     SAL_WARN_IF( !xOwner.is(), "fwk", "OFrames::remove(): Our owner is dead - you can't remove any frames ...!" );
 }
 
@@ -193,7 +193,7 @@ Sequence< css::uno::Reference< XFrame > > SAL_CALL OFrames::queryFrames( sal_Int
             }
         }
     }
-    // Else; Do nothing! Ouer owner is dead.
+    // Else; Do nothing! Our owner is dead.
     SAL_WARN_IF( !xOwner.is(), "fwk", "OFrames::queryFrames(): Our owner is dead - you can't query for frames ...!" );
 
     // Resturn result of this operation.
@@ -348,8 +348,8 @@ void OFrames::impl_appendSequence(          Sequence< css::uno::Reference< XFram
 -----------------------------------------------------------------------------------------------------------------*/
 
 // An instance of this class can only work with valid initialization.
-// We share the mutex with ouer owner class, need a valid factory to instanciate new services and
-// use the access to ouer owner for some operations.
+// We share the mutex with our owner class, need a valid factory to instanciate new services and
+// use the access to our owner for some operations.
 sal_Bool OFrames::impldbg_checkParameter_OFramesCtor(   const   css::uno::Reference< XFrame >&              xOwner          ,
                                                                 FrameContainer*                     pFrameContainer )
 {
diff --git a/include/unotools/historyoptions.hxx b/include/unotools/historyoptions.hxx
index 7a41bf5..46571bc 100644
--- a/include/unotools/historyoptions.hxx
+++ b/include/unotools/historyoptions.hxx
@@ -39,7 +39,7 @@
 #define HISTORY_PROPERTYNAME_THUMBNAIL      OUString("Thumbnail")
 
 /*-************************************************************************************************************
-    @descr          You can use these enum values to specify right history if you call ouer interface methods.
+    @descr          You can use these enum values to specify right history if you call our interface methods.
 *//*-*************************************************************************************************************/
 
 enum EHistoryType
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OnewayExecutor.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OnewayExecutor.java
index bd8db66..dd2eb77 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OnewayExecutor.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OnewayExecutor.java
@@ -120,7 +120,7 @@ class OnewayExecutor extends Thread
      * implements the thread function
      * Here we call the internal set link object back and
      * give him all necessary parameters.
-     * After that we die by ouerself ...
+     * After that we die by ourselves ...
      */
     public void run()
     {
diff --git a/unotools/source/config/cmdoptions.cxx b/unotools/source/config/cmdoptions.cxx
index eb28d24..0a2c869 100644
--- a/unotools/source/config/cmdoptions.cxx
+++ b/unotools/source/config/cmdoptions.cxx
@@ -187,7 +187,7 @@ SvtCommandOptions_Impl::SvtCommandOptions_Impl()
     // Follow assignment use order of values in relation to our list of key names!
     DBG_ASSERT( !(lNames.getLength()!=lValues.getLength()), "SvtCommandOptions_Impl::SvtCommandOptions_Impl()\nI miss some values of configuration keys!\n" );
 
-    // Copy values from list in right order to ouer internal member.
+    // Copy values from list in right order to our internal member.
     // Attention: List for names and values have an internal construction pattern!
     sal_Int32   nItem     = 0;
     OUString    sCmd;
@@ -201,8 +201,8 @@ SvtCommandOptions_Impl::SvtCommandOptions_Impl()
     }
 
 /*TODO: Not used in the moment! see Notify() ...
-    // Enable notification mechanism of ouer baseclass.
-    // We need it to get information about changes outside these class on ouer used configuration keys! */
+    // Enable notification mechanism of our baseclass.
+    // We need it to get information about changes outside these class on our used configuration keys! */
     Sequence< OUString > aNotifySeq( 1 );
     aNotifySeq[0] = "Disabled";
     EnableNotification( aNotifySeq, true );
@@ -233,7 +233,7 @@ void SvtCommandOptions_Impl::Notify( const Sequence< OUString >& )
     // Follow assignment use order of values in relation to our list of key names!
     DBG_ASSERT( !(lNames.getLength()!=lValues.getLength()), "SvtCommandOptions_Impl::Notify()\nI miss some values of configuration keys!\n" );
 
-    // Copy values from list in right order to ouer internal member.
+    // Copy values from list in right order to our internal member.
     // Attention: List for names and values have an internal construction pattern!
     sal_Int32   nItem     = 0;
     OUString    sCmd;
@@ -347,9 +347,9 @@ SvtCommandOptions::SvtCommandOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new SvtCommandOptions_Impl;
@@ -363,10 +363,10 @@ SvtCommandOptions::~SvtCommandOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
diff --git a/unotools/source/config/compatibility.cxx b/unotools/source/config/compatibility.cxx
index d3fd808..a12b395 100644
--- a/unotools/source/config/compatibility.cxx
+++ b/unotools/source/config/compatibility.cxx
@@ -597,9 +597,9 @@ SvtCompatibilityOptions::SvtCompatibilityOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new SvtCompatibilityOptions_Impl;
@@ -613,10 +613,10 @@ SvtCompatibilityOptions::~SvtCompatibilityOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
diff --git a/unotools/source/config/dynamicmenuoptions.cxx b/unotools/source/config/dynamicmenuoptions.cxx
index 8982adc..6763595 100644
--- a/unotools/source/config/dynamicmenuoptions.cxx
+++ b/unotools/source/config/dynamicmenuoptions.cxx
@@ -339,7 +339,7 @@ SvtDynamicMenuOptions_Impl::SvtDynamicMenuOptions_Impl()
     // Follow assignment use order of values in relation to our list of key names!
     DBG_ASSERT( !(lNames.getLength()!=lValues.getLength()), "SvtDynamicMenuOptions_Impl::SvtDynamicMenuOptions_Impl()\nI miss some values of configuration keys!\n" );
 
-    // Copy values from list in right order to ouer internal member.
+    // Copy values from list in right order to our internal member.
     // Attention: List for names and values have an internal construction pattern!
 
     // first "New" menu ...
@@ -418,8 +418,8 @@ SvtDynamicMenuOptions_Impl::SvtDynamicMenuOptions_Impl()
     }
 
 /*TODO: Not used in the moment! see Notify() ...
-    // Enable notification mechanism of ouer baseclass.
-    // We need it to get information about changes outside these class on ouer used configuration keys!
+    // Enable notification mechanism of our baseclass.
+    // We need it to get information about changes outside these class on our used configuration keys!
     EnableNotification( lNames );
 */
 }
@@ -669,9 +669,9 @@ SvtDynamicMenuOptions::SvtDynamicMenuOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new SvtDynamicMenuOptions_Impl;
@@ -685,10 +685,10 @@ SvtDynamicMenuOptions::~SvtDynamicMenuOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
diff --git a/unotools/source/config/historyoptions.cxx b/unotools/source/config/historyoptions.cxx
index c156158..272cc31 100644
--- a/unotools/source/config/historyoptions.cxx
+++ b/unotools/source/config/historyoptions.cxx
@@ -566,9 +566,9 @@ SvtHistoryOptions::SvtHistoryOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new SvtHistoryOptions_Impl;
@@ -583,10 +583,10 @@ SvtHistoryOptions::~SvtHistoryOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
diff --git a/unotools/source/config/moduleoptions.cxx b/unotools/source/config/moduleoptions.cxx
index aed3543..8e2e3c1 100644
--- a/unotools/source/config/moduleoptions.cxx
+++ b/unotools/source/config/moduleoptions.cxx
@@ -703,7 +703,7 @@ void SvtModuleOptions_Impl::SetFactoryDefaultFilter(       SvtModuleOptions::EFa
 }
 
 /*-************************************************************************************************************
-    @short      return list of key names of ouer configuration management which represent our module tree
+    @short      return list of key names of our configuration management which represent our module tree
     @descr      You give use a list of current existing set node names .. and we expand it for all
                 well known properties which are necessary for this implementation.
                 These full expanded list should be used to get values of this properties.
diff --git a/unotools/source/config/printwarningoptions.cxx b/unotools/source/config/printwarningoptions.cxx
index 297d8cb..40faa76 100644
--- a/unotools/source/config/printwarningoptions.cxx
+++ b/unotools/source/config/printwarningoptions.cxx
@@ -237,9 +237,9 @@ SvtPrintWarningOptions::SvtPrintWarningOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already!
+    // ... and initialize our data container only if it not already!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new SvtPrintWarningOptions_Impl();
@@ -253,10 +253,10 @@ SvtPrintWarningOptions::~SvtPrintWarningOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
diff --git a/unotools/source/config/securityoptions.cxx b/unotools/source/config/securityoptions.cxx
index c164464..7906ed7 100644
--- a/unotools/source/config/securityoptions.cxx
+++ b/unotools/source/config/securityoptions.cxx
@@ -154,7 +154,7 @@ class SvtSecurityOptions_Impl : public ConfigItem
         bool                IsOptionEnabled ( SvtSecurityOptions::EOption eOption                   ) const;
 
         /*-****************************************************************************************************
-            @short      return list of key names of ouer configuration management which represent our module tree
+            @short      return list of key names of our configuration management which represent our module tree
             @descr      These methods return a static const list of key names. We need it to get needed values from our
                         configuration management.
             @return     A list of needed configuration keys is returned.
@@ -967,9 +967,9 @@ SvtSecurityOptions::SvtSecurityOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetInitMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new SvtSecurityOptions_Impl;
@@ -982,10 +982,10 @@ SvtSecurityOptions::~SvtSecurityOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetInitMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;


More information about the Libreoffice-commits mailing list
diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index a7d0504..cb23425 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -519,7 +519,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Desktop::getCurrentFrame() th
     // Register transaction and reject wrong calls.
     TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
 
     // Start search with ouer direct active frame (if it exist!).
     // Search on his children for other active frames too.
     // Stop if no one could be found and return last of found ones.
     css::uno::Reference< css::frame::XFramesSupplier > xLast = css::uno::Reference< css::frame::XFramesSupplier >( getActiveFrame(), css::uno::UNO_QUERY );
@@ -571,7 +571,7 @@ css::uno::Reference< css::lang::XComponent > SAL_CALL Desktop::loadComponentFrom
 
 /*-************************************************************************************************************
     @interface  XTasksSupplier
-    @short      get access to create enumerations of ouer taskchildren
+    @short      get access to create enumerations of our taskchildren
     @descr      Direct children of desktop are tasks everytime.
                 Call these method to could create enumerations of it.
 
@@ -583,7 +583,7 @@ But; Don't forget - you will be the owner of returned object and must release it
     @attention  Normaly we don't need any lock here. We don't work on internal member!
 
     @seealso    class TasksAccess
-    @return     A reference to an accessobject, which can create enumerations of ouer childtasks.
+    @return     A reference to an accessobject, which can create enumerations of our childtasks.
 
     @onerror    A null reference is returned.
     @threadsafe yes
@@ -596,16 +596,16 @@ css::uno::Reference< css::container::XEnumerationAccess > SAL_CALL Desktop::getT
 
 /*-************************************************************************************************************
     @interface  XTasksSupplier
-    @short      return current active task of ouer direct children
+    @short      return current active task of our direct children
     @descr      Desktop children are tasks only ! If we have an active path from desktop
                 as top to any frame on bottom, we must have an active direct child. His reference is returned here.
 
-    @attention  a)  Do not confuse it with getCurrentFrame()! The current frame don't must one of ouer direct children.
+    @attention  a)  Do not confuse it with getCurrentFrame()! The current frame don't must one of our direct children.
                     It can be every frame in subtree and must have the focus (Is the last one of an active path!).
                 b)  We don't need any lock here. Our container is threadsafe himself and live, if we live!
 
     @seealso    method getCurrentFrame()
-    @return     A reference to ouer current active taskchild.
+    @return     A reference to our current active taskchild.
 
     @onerror    A null reference is returned.
     @threadsafe yes
@@ -728,7 +728,7 @@ css::uno::Reference< css::frame::XFrames > SAL_CALL Desktop::getFrames() throw(
     @interface  XFramesSupplier
     @short      set/get the current active child frame
     @descr      It must be a task. Direct children of desktop are tasks only! No frames are accepted.
-                We don't save this information directly in this class. We use ouer container-helper
+                We don't save this information directly in this class. We use our container-helper
                 to do that.
 
     @attention  Helper is threadsafe himself. So we don't need any lock here.
@@ -736,7 +736,7 @@ css::uno::Reference< css::frame::XFrames > SAL_CALL Desktop::getFrames() throw(
     @seealso    class OFrameContainer
 
     @param      "xFrame", new active frame (must be valid!)
-    @return     A reference to ouer current active childtask, if anyone exist.
+    @return     A reference to our current active childtask, if anyone exist.
 
     @onerror    A null reference is returned.
     @threadsafe yes
@@ -519,7 +519,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Desktop::getCurrentFrame() th
     TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
 
-    // Start search with ouer direct active frame (if it exist!).
+    // Start search with our direct active frame (if it exist!).
     // Search on his children for other active frames too.
     // Stop if no one could be found and return last of found ones.
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index 74225e9..8f23fc3 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -676,19 +676,19 @@ css::uno::Reference< css::frame::XFrames > SAL_CALL Frame::getFrames() throw( cs
 
     SolarMutexGuard g;
     // Return access to all child frames to caller.
     // Ouer childframe container is implemented in helper class OFrames and used as a reference m_xFramesHelper!
     return m_xFramesHelper;
 }
 
 /*-****************************************************************************************************
     @short      get the current active child frame
     @descr      It must be a frameto. Direct children of a frame are frames only! No task or desktop is accepted.
-                We don't save this information directly in this class. We use ouer container-helper
+                We don't save this information directly in this class. We use our container-helper
                 to do that.
 
     @seealso    class OFrameContainer
     @seealso    method setActiveFrame()
-    @return     A reference to ouer current active childframe, if anyone exist.
+    @return     A reference to our current active childframe, if anyone exist.
     @return     A null reference, if nobody is active.
 
     @onerror    A null reference is returned.
@@ -708,7 +708,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Frame::getActiveFrame() throw
 /*-****************************************************************************************************
     @short      set the new active direct child frame
     @descr      It must be a frame to. Direct children of frame are frames only! No task or desktop is accepted.
-                We don't save this information directly in this class. We use ouer container-helper
+                We don't save this information directly in this class. We use our container-helper
                 to do that.
 
     @seealso    class OFrameContainer
@@ -1295,7 +1295,7 @@ sal_Bool SAL_CALL Frame::isTop() throw( css::uno::RuntimeException, std::excepti
 
     SolarMutexGuard g;
     // This information is set in setCreator().
     // We are top, if ouer parent is a task or the desktop or if no parent exist!
     return m_bIsFrameTop;
 }
 
@@ -1365,7 +1365,7 @@ void SAL_CALL Frame::activate() throw( css::uno::RuntimeException, std::exceptio
     }
 
     //  2)  I was active before or current activated and there is a path from here to bottom, who CAN be active.
     //      But ouer direct child of path is not active yet.
     //      (It can be, if activation occur in the middle of a current path!)
     //      In these case we activate path to bottom to set focus on right frame!
     if ( eState == E_ACTIVE && xActiveChild.is() && !xActiveChild->isActive() )
@@ -1448,11 +1448,11 @@ void SAL_CALL Frame::deactivate() throw( css::uno::RuntimeException, std::except
         //  4)  If there is a path from here to my parent ...
         //      ... I'am on the top or in the middle of deactivated subtree and action was started here.
         //      I must deactivate all frames from here to top, which are members of current path.
         //      Stop, if THESE frame not the active frame of ouer parent!
         if ( xParent.is() && xParent->getActiveFrame() == xThis )
         {
             // We MUST break the path - otherwise we will get the focus - not ouer parent! ...
             // Attention: Ouer parent don't call us again - WE ARE NOT ACTIVE YET!
             // [ see step 3 and condition "if ( m_eActiveState!=INACTIVE ) ..." in this method! ]
             xParent->deactivate();
         }
@@ -676,19 +676,19 @@ css::uno::Reference< css::frame::XFrames > SAL_CALL Frame::getFrames() throw( cs
     SolarMutexGuard g;
     // Return access to all child frames to caller.
-    // Ouer childframe container is implemented in helper class OFrames and used as a reference m_xFramesHelper!
+    // Our childframe container is implemented in helper class OFrames and used as a reference m_xFramesHelper!
     return m_xFramesHelper;
 }
@@ -1295,7 +1295,7 @@ sal_Bool SAL_CALL Frame::isTop() throw( css::uno::RuntimeException, std::excepti
     SolarMutexGuard g;
     // This information is set in setCreator().
-    // We are top, if ouer parent is a task or the desktop or if no parent exist!
+    // We are top, if our parent is a task or the desktop or if no parent exist!
     return m_bIsFrameTop;
 }
@@ -1365,7 +1365,7 @@ void SAL_CALL Frame::activate() throw( css::uno::RuntimeException, std::exceptio
 
     //  2)  I was active before or current activated and there is a path from here to bottom, who CAN be active.
-    //      But ouer direct child of path is not active yet.
+    //      But our direct child of path is not active yet.
     //      (It can be, if activation occur in the middle of a current path!)
     //      In these case we activate path to bottom to set focus on right frame!
@@ -1448,11 +1448,11 @@ void SAL_CALL Frame::deactivate() throw( css::uno::RuntimeException, std::except
         //      ... I'am on the top or in the middle of deactivated subtree and action was started here.
         //      I must deactivate all frames from here to top, which are members of current path.
-        //      Stop, if THESE frame not the active frame of ouer parent!
+        //      Stop, if THESE frame not the active frame of our parent!
         if ( xParent.is() && xParent->getActiveFrame() == xThis )
         {
@@ -1448,11 +1448,11 @@ void SAL_CALL Frame::deactivate() throw( css::uno::RuntimeException, std::except
         if ( xParent.is() && xParent->getActiveFrame() == xThis )
         {
-            // We MUST break the path - otherwise we will get the focus - not ouer parent! ...
-            // Attention: Ouer parent don't call us again - WE ARE NOT ACTIVE YET!
+            // We MUST break the path - otherwise we will get the focus - not our parent! ...
+            // Attention: Our parent don't call us again - WE ARE NOT ACTIVE YET!
             // [ see step 3 and condition "if ( m_eActiveState!=INACTIVE ) ..." in this method! ]
             xParent->deactivate();
diff --git a/unotools/source/config/extendedsecurityoptions.cxx b/unotools/source/config/extendedsecurityoptions.cxx
index b69da51..06f6445 100644
--- a/unotools/source/config/extendedsecurityoptions.cxx
+++ b/unotools/source/config/extendedsecurityoptions.cxx
@@ -92,7 +92,7 @@ class SvtExtendedSecurityOptions_Impl : public ConfigItem
     private:
 
         /*-****************************************************************************************************
-            @short      return list of key names of ouer configuration management which represent oue module tree
+            @short      return list of key names of our configuration management which represent oue module tree
             @descr      These methods return a static const list of key names. We need it to get needed values from our
                         configuration management.
             @return     A list of needed configuration keys is returned.
@@ -159,7 +159,7 @@ SvtExtendedSecurityOptions_Impl::SvtExtendedSecurityOptions_Impl()
     }
 
     // Enable notification mechanism of our baseclass.
     // We need it to get information about changes outside these class on ouer used configuration keys!
     Sequence< OUString > seqNotifyNames( 1 );
     seqNotifyNames[0] = m_aSecureExtensionsSetName;
     EnableNotification( seqNotifyNames );
@@ -275,9 +275,9 @@ SvtExtendedSecurityOptions::SvtExtendedSecurityOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetInitMutex() );
     // Increase ouer refcount ...
     ++m_nRefCount;
     // ... and initialize ouer data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
        m_pDataContainer = new SvtExtendedSecurityOptions_Impl;
@@ -292,10 +292,10 @@ SvtExtendedSecurityOptions::~SvtExtendedSecurityOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetInitMutex() );
     // Decrease ouer refcount.
     --m_nRefCount;
     // If last instance was deleted ...
     // we must destroy ouer static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
@@ -159,7 +159,7 @@ SvtExtendedSecurityOptions_Impl::SvtExtendedSecurityOptions_Impl()
 
     // Enable notification mechanism of our baseclass.
-    // We need it to get information about changes outside these class on ouer used configuration keys!
+    // We need it to get information about changes outside these class on our used configuration keys!
     Sequence< OUString > seqNotifyNames( 1 );
     seqNotifyNames[0] = m_aSecureExtensionsSetName;
@@ -275,9 +275,9 @@ SvtExtendedSecurityOptions::SvtExtendedSecurityOptions()
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetInitMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
@@ -275,9 +275,9 @@ SvtExtendedSecurityOptions::SvtExtendedSecurityOptions()
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
@@ -292,10 +292,10 @@ SvtExtendedSecurityOptions::~SvtExtendedSecurityOptions()
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetInitMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
@@ -292,10 +292,10 @@ SvtExtendedSecurityOptions::~SvtExtendedSecurityOptions()
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
diff --git a/unotools/source/config/fontoptions.cxx b/unotools/source/config/fontoptions.cxx
index 5073901..1032179 100644
--- a/unotools/source/config/fontoptions.cxx
+++ b/unotools/source/config/fontoptions.cxx
@@ -76,7 +76,7 @@ class SvtFontOptions_Impl : public ConfigItem
 
         /*-****************************************************************************************************
             @short      access method to get internal values
-            @descr      These method give us a chance to regulate acces to ouer internal values.
+            @descr      These method give us a chance to regulate acces to our internal values.
                         It's not used in the moment - but it's possible for the feature!
         *//*-*****************************************************************************************************/
 
@@ -89,7 +89,7 @@ class SvtFontOptions_Impl : public ConfigItem
     private:
 
         /*-****************************************************************************************************
-            @short      return list of key names of ouer configuration management which represent oue module tree
+            @short      return list of key names of our configuration management which represent oue module tree
             @descr      These methods return a static const list of key names. We need it to get needed values from our
                         configuration management.
             @return     A list of needed configuration keys is returned.
@@ -123,7 +123,7 @@ SvtFontOptions_Impl::SvtFontOptions_Impl()
     // Follow assignment use order of values in relation to our list of key names!
     DBG_ASSERT( !(seqNames.getLength()!=seqValues.getLength()), "SvtFontOptions_Impl::SvtFontOptions_Impl()\nI miss some values of configuration keys!\n" );
 
     // Copy values from list in right order to ouer internal member.
     sal_Int32 nPropertyCount = seqValues.getLength();
     for( sal_Int32 nProperty=0; nProperty<nPropertyCount; ++nProperty )
     {
@@ -150,8 +150,8 @@ SvtFontOptions_Impl::SvtFontOptions_Impl()
         }
     }
 
     // Enable notification mechanism of ouer baseclass.
     // We need it to get information about changes outside these class on ouer used configuration keys!
     EnableNotification( seqNames );
 }
 
@@ -292,9 +292,9 @@ SvtFontOptions::SvtFontOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( impl_GetOwnStaticMutex() );
     // Increase ouer refcount ...
     ++m_nRefCount;
     // ... and initialize ouer data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new SvtFontOptions_Impl;
@@ -309,10 +309,10 @@ SvtFontOptions::~SvtFontOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( impl_GetOwnStaticMutex() );
     // Decrease ouer refcount.
     --m_nRefCount;
     // If last instance was deleted ...
     // we must destroy ouer static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
@@ -123,7 +123,7 @@ SvtFontOptions_Impl::SvtFontOptions_Impl()
     DBG_ASSERT( !(seqNames.getLength()!=seqValues.getLength()), "SvtFontOptions_Impl::SvtFontOptions_Impl()\nI miss some values of configuration keys!\n" );
 
-    // Copy values from list in right order to ouer internal member.
+    // Copy values from list in right order to our internal member.
     sal_Int32 nPropertyCount = seqValues.getLength();
     for( sal_Int32 nProperty=0; nProperty<nPropertyCount; ++nProperty )
@@ -150,8 +150,8 @@ SvtFontOptions_Impl::SvtFontOptions_Impl()
     }
 
-    // Enable notification mechanism of ouer baseclass.
-    // We need it to get information about changes outside these class on ouer used configuration keys!
+    // Enable notification mechanism of our baseclass.
+    // We need it to get information about changes outside these class on our used configuration keys!
     EnableNotification( seqNames );
 }
@@ -292,9 +292,9 @@ SvtFontOptions::SvtFontOptions()
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( impl_GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
@@ -292,9 +292,9 @@ SvtFontOptions::SvtFontOptions()
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
@@ -309,10 +309,10 @@ SvtFontOptions::~SvtFontOptions()
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( impl_GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
@@ -309,10 +309,10 @@ SvtFontOptions::~SvtFontOptions()
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
diff --git a/unotools/source/config/localisationoptions.cxx b/unotools/source/config/localisationoptions.cxx
index 186ff13..d5c6daf 100644
--- a/unotools/source/config/localisationoptions.cxx
+++ b/unotools/source/config/localisationoptions.cxx
@@ -75,7 +75,7 @@ class SvtLocalisationOptions_Impl : public ConfigItem
 
         /*-****************************************************************************************************
             @short      access method to get internal values
-            @descr      These method give us a chance to regulate acces to ouer internal values.
+            @descr      These method give us a chance to regulate acces to our internal values.
                         It's not used in the moment - but it's possible for the feature!
         *//*-*****************************************************************************************************/
 
@@ -85,7 +85,7 @@ class SvtLocalisationOptions_Impl : public ConfigItem
     private:
 
         /*-****************************************************************************************************
-            @short      return list of key names of ouer configuration management which represent oue module tree
+            @short      return list of key names of our configuration management which represent oue module tree
             @descr      These methods return a static const list of key names. We need it to get needed values from our
                         configuration management.
             @return     A list of needed configuration keys is returned.
@@ -139,8 +139,8 @@ SvtLocalisationOptions_Impl::SvtLocalisationOptions_Impl()
         }
     }
 
     // Enable notification mechanism of ouer baseclass.
     // We need it to get information about changes outside these class on ouer used configuration keys!
     EnableNotification( seqNames );
 }
 
@@ -255,9 +255,9 @@ SvtLocalisationOptions::SvtLocalisationOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
     // Increase ouer refcount ...
     ++m_nRefCount;
     // ... and initialize ouer data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new SvtLocalisationOptions_Impl;
@@ -272,10 +272,10 @@ SvtLocalisationOptions::~SvtLocalisationOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
     // Decrease ouer refcount.
     --m_nRefCount;
     // If last instance was deleted ...
     // we must destroy ouer static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
@@ -139,8 +139,8 @@ SvtLocalisationOptions_Impl::SvtLocalisationOptions_Impl()
     }
 
-    // Enable notification mechanism of ouer baseclass.
-    // We need it to get information about changes outside these class on ouer used configuration keys!
+    // Enable notification mechanism of our baseclass.
+    // We need it to get information about changes outside these class on our used configuration keys!
     EnableNotification( seqNames );
 }
@@ -255,9 +255,9 @@ SvtLocalisationOptions::SvtLocalisationOptions()
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
@@ -255,9 +255,9 @@ SvtLocalisationOptions::SvtLocalisationOptions()
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
@@ -272,10 +272,10 @@ SvtLocalisationOptions::~SvtLocalisationOptions()
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
@@ -272,10 +272,10 @@ SvtLocalisationOptions::~SvtLocalisationOptions()
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {